@@ -1,3 +1,5 @@
+use 5.008;
+
 package Test::Data::Scalar;
 use strict;
 
@@ -11,7 +13,7 @@ our @EXPORT = qw(
 	string_between_ok
 	);
 
-our $VERSION = '1.241';
+our $VERSION = '1.243';
 
 use Scalar::Util;
 use Test::Builder;
@@ -451,10 +453,10 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2002-2016, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright © 2002-2021, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the terms of the Artistic License 2.0.
 
 =cut
 
